@@ -7,18 +7,20 @@
 # You may use and distribute this software under the same terms and conditions
 # as Perl itself.
 
-package PkgConfig::Vars;
+package
+    PkgConfig::Vars;
 # this is a namespace for .pc files to hold their variables without
 # relying on lexical scope.
 
-package PkgConfig::UDefs;
+package
+    PkgConfig::UDefs;
 # This namespace provides user-defined variables which are to override any
 # declarations within the .pc file itself.
 
 package PkgConfig;
 
 #First two digits are Perl version, second two are pkg-config version
-our $VERSION = '0.07520';
+our $VERSION = '0.07820';
 
 require 5.006;
 
@@ -28,9 +30,10 @@ use Config;
 use File::Spec;
 use File::Glob 'bsd_glob';
 use Class::Struct; #in core since 5.004
-our $UseDebugging;
-
 use Data::Dumper;
+use File::Basename qw( dirname );
+
+our $UseDebugging;
 
 ################################################################################
 ### Check for Log::Fu                                                        ###
@@ -65,7 +68,11 @@ our @DEFAULT_SEARCH_PATH = qw(
 
 );
 
-if($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
+if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+
+    # use the defaults regardless of detected platform
+
+} elsif($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
     if(-x "/usr/bin/dpkg-architecture") {
         my $arch = `/usr/bin/dpkg-architecture -qDEB_HOST_MULTIARCH`;
         chomp $arch;
@@ -146,10 +153,12 @@ if($^O =~ /^(gnukfreebsd|linux)$/ && -r "/etc/debian_version") {
     require Config;
     if($Config::Config{myuname} =~ /strawberry-perl/)
     {
-        my($vol, $dir, $file) = File::Spec->splitpath($INC{"Config.pm"});
+        my($vol, $dir, $file) = File::Spec->splitpath($^X);
         my @dirs = File::Spec->splitdir($dir);
         splice @dirs, -3;
-        @DEFAULT_SEARCH_PATH = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
+        my $path = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
+        $path =~ s{\\}{/}g;
+        @DEFAULT_SEARCH_PATH = $path;
     }
 
 }
@@ -168,6 +177,53 @@ our @DEFAULT_EXCLUDE_LFLAGS = qw(
     -R/lib -R/usr/lib -R/usr/lib64 -R/lib32 -R/lib64 -R/usr/local/lib
 );
 
+if($ENV{PKG_CONFIG_NO_OS_CUSTOMIZATION}) {
+
+    # use the defaults regardless of detected platform
+
+} elsif($^O eq 'MSWin32') {
+
+    if($Config::Config{cc} =~ /cl(\.exe)?$/i)
+    {
+        @DEFAULT_EXCLUDE_LFLAGS = ();
+        @DEFAULT_EXCLUDE_CFLAGS = ();
+    }
+    else
+    {
+        @DEFAULT_EXCLUDE_LFLAGS = (
+            "-L/mingw/lib",
+            "-R/mingw/lib",
+            "-L/mingw/lib/pkgconfig/../../lib",
+            "-R/mingw/lib/pkgconfig/../../lib",
+        );
+        @DEFAULT_EXCLUDE_CFLAGS = (
+            "-I/mingw/include",
+            "-I/mingw/lib/pkgconfig/../../include",
+        );
+    }
+    
+    # See caveats above for Strawberry
+    require Config;
+    if($Config::Config{myuname} =~ /strawberry-perl/)
+    {
+        my($vol, $dir, $file) = File::Spec->splitpath($^X);
+        my @dirs = File::Spec->splitdir($dir);
+        splice @dirs, -3;
+        my $path = (File::Spec->catdir($vol, @dirs, qw( c )));
+        $path =~ s{\\}{/}g;
+        push @DEFAULT_EXCLUDE_LFLAGS, (
+            "-L$path/lib",
+            "-L$path/lib/pkgconfig/../../lib",
+            "-R$path/lib",
+            "-R$path/lib/pkgconfig/../../lib",
+        );
+        push @DEFAULT_EXCLUDE_CFLAGS, (
+            "-I$path/include",
+            "-I$path/lib/pkgconfig/../../include",
+        );
+    }
+}
+
 
 my $LD_OUTPUT_RE = qr/
     SEARCH_DIR\("
@@ -402,7 +458,19 @@ sub find {
     
         foreach my $lib (@libraries) {
             $o->recursion(0);
+            my($op,$ver);
+            ($lib,$op,$ver) = ($1,$2,PkgConfig::Version->new($3))
+                if $lib =~ /^(.*)\s+(!=|=|>=|<=|>|<)\s+(.*)$/;
             $o->find_pcfile($lib);
+            
+            if(!$o->errmsg && defined $op) {
+                $op = '==' if $op eq '=';
+                unless(eval qq{ PkgConfig::Version->new(\$o->pkg_version) $op \$ver })
+                {
+                    $o->errmsg("Requested '$lib $op $ver' but version of $lib is " . 
+                        ($o->pkg_version ? $o->pkg_version : '') . "\n");
+                }
+            }
         }
     }
     
@@ -565,7 +633,10 @@ sub parse_pcfile {
     
     #Fold lines:
     
-    foreach my $line (@lines) {
+    my $pcfiledir = dirname $pcfile;
+    $pcfiledir =~ s{\\}{/}g;
+
+    foreach my $line ("pcfiledir=$pcfiledir", @lines) {
         $self->parse_line($line, \@eval_strings);
     }
     
@@ -676,6 +747,11 @@ sub get_ldflags {
     return @ret;
 }
 
+sub get_var {
+    my($self, $name) = @_;
+    $self->_pc_var($name);
+}
+
 sub get_list {
     my $self = shift;
     my @search_paths = @{$self->search_path};
@@ -783,6 +859,34 @@ if(caller) {
     return 1;
 }
 
+package
+    PkgConfig::Version;
+
+use overload
+    '<=>' => sub { $_[0]->cmp($_[1]) },
+    '""'  => sub { $_[0]->as_string },
+    fallback => 1;
+
+sub new {
+    my($class, $value) = @_;
+    bless [split /\./, defined $value ? $value : ''], $class;
+}
+
+sub clone {
+    __PACKAGE__->new(shift->as_string);
+}
+
+sub as_string {
+    my($self) = @_;
+    join '.', @{ $self };
+}
+
+sub cmp {
+    my($self, $other) = @_;
+    no warnings 'uninitialized';
+    defined($self->[0]) || defined($other->[0]) ? ($self->[0] <=> $other->[0]) || &cmp([@{$self}[1..$#$self]], [@{$other}[1..$#$other]]) : 0;
+}
+
 ################################################################################
 ################################################################################
 ################################################################################
@@ -920,6 +1024,15 @@ if($ListAll) {
 }
 
 my @FINDLIBS = @ARGV or die "Must specify at least one library";
+
+if($AtLeastVersion) {
+    @FINDLIBS = map { "$_ >= $AtLeastVersion" } @FINDLIBS;
+} elsif($MaxVersion) {
+    @FINDLIBS = map { "$_ <= $MaxVersion" } @FINDLIBS;
+} elsif($ExactVersion) {
+    @FINDLIBS = map { "$_ = $ExactVersion" } @FINDLIBS;
+}
+
 my $o = PkgConfig->find(\@FINDLIBS, %pc_options);
 
 if($o->errmsg) {
@@ -927,31 +1040,6 @@ if($o->errmsg) {
     exit(1);
 }
 
-if($ExactVersion) {
-    exit(2) unless $o->pkg_version eq $ExactVersion;
-}
-
-sub _is_greater_than_or_equal ($$)
-{
-    my @a = split /\./, shift;
-    my @b = split /\./, shift;
-    while(@a || @b) {
-        my $a = shift(@a) || 0;
-        my $b = shift(@b) || 0;
-        return 1 if $a > $b;
-        return 0 if $a < $b;
-    }
-    return 1;
-}
-
-if($AtLeastVersion) {
-    exit(2) unless _is_greater_than_or_equal($o->pkg_version, $AtLeastVersion);
-}
-
-if($MaxVersion) {
-    exit(2) unless _is_greater_than_or_equal($MaxVersion, $o->pkg_version);
-}
-
 if($o->print_variables) {
     while (my ($k,$v) = each %{$o->defined_variables}) {
         print $k;
@@ -998,13 +1086,6 @@ if($PrintLibsOnlyl or ($PrintLibsOnlyl and $PrintLibsOnlyL)) {
 print "\n";
 exit(0);
 
-# workaround for
-# https://rt.cpan.org/Ticket/Display.html?id=96132&results=7cdf596d4e44d8f4ed9862124b28fd59
-sub run {
-    system $^X, __FILE__, @_;
-    exit $? >> 8
-}
-
 __END__
 
 =head1 NAME
@@ -1024,7 +1105,7 @@ PkgConfig - Pure-Perl Core-Only replacement for pkg-config
 
 C<pkg-config.pl> can be used as an alias for C<ppkg-config> on platforms that
 support it.  It can also be installed as C<pkg-config> though this is not
-recomended if your system has a nativ C<pkg-config>.
+recomended if your system has a native C<pkg-config>.
 
 Compare to:
     $ pkg-config --libs --cflags --static gio-2.0
@@ -1043,6 +1124,7 @@ Compare to:
     if($o->errmsg) {
         #handle error
     } else {
+        my $prefix = $o->get_var('prefix');
         my @cflags = $o->get_cflags;
         my @ldflags = $o->get_ldflags;
     }
@@ -1056,7 +1138,7 @@ This is not a description of the uses of C<pkg-config> but rather a description
 of the differences between the C version and the Perl one.
 
 While C<pkg-config> is a compiled binary linked with glib, the pure-perl version
-has no such requirement, and will run wherever Perl ( >= 5.04 ) does.
+has no such requirement, and will run wherever Perl ( >= 5.6 ) does.
 
 The main supported options are the common C<--libs>, C<--cflags>,
 C<--static>, C<--exists> and C<--modversion>.
@@ -1166,8 +1248,8 @@ C<--silence-errors>
 
 =head3 ENVIRONMENT
 
-the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited list
-of directories with contain C<.pc> files.
+the C<PKG_CONFIG_PATH> variable is honored and used as a colon-delimited 
+(semicolon-delimited on Windows) list of directories with contain C<.pc> files.
 
 =head2 MODULE OPTIONS
 
@@ -1254,6 +1336,10 @@ The version of the package
 
 Returns a list of compiler and linker flags, respectively.
 
+=head4 I<< $o->get_var($name) >>
+
+Get the variable with the given name.
+
 =head4 I<< PkgConfig->Guess >>
 
 This is a class method, and will replace the hard-coded default linker and include
@@ -1296,6 +1382,35 @@ Example, don't install any scripts:
 
  % perl Makefile.PL --script none
 
+You can also set the environment variable PERL_PKG_CONFIG_SCRIPTS to the
+desired --script value (separating each script name with a comma C<,>) to
+ensure that upgrades of PkgConfig do the same.
+
+=head2 CAVEATS
+
+On Strawberry Perl C<ppkg-config> acts like Strawberry is the system.  
+This means that
+
+=over 4
+
+=item
+
+The .pc files that are bundled with Strawberry are searched by default.
+
+=item
+
+The Strawberry include and lib directories are used to compute the 
+exclusion lists.
+
+=back
+
+As of Strawberry 5.20.0.1 PkgConfig is bundled with Strawberry and 
+C<pkg-config> is installed by default (in addition to C<ppkg-config>,
+though the C<ppkg-config> alias is NOT bundled with Strawberry itself).
+
+For details on how to patch the .pc files bundled with older Strawberries,
+see the C<README.win32> that comes with this Distribution.
+
 =head2 BUGS
 
 The order of the flags is not exactly matching to that of C<pkg-config>. From my
@@ -1308,12 +1423,34 @@ package itself (without dependencies).
 
 =head1 SEE ALSO
 
-L<ExtUtils::PkgConfig>, a wrapper around the C<pkg-config> binary
+=over 4
 
-L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
+=item L<pkg-config|http://www.freedesktop.org/wiki/Software/pkg-config>
 
-L<http://www.openbsd.org/cgi-bin/cvsweb/src/usr.bin/pkg-config/> another 
-perl implementation of pkg-config
+The original C implementation
+
+=item L<ExtUtils::PkgConfig>
+
+A wrapper around the C<pkg-config> binary that can be used in your C<Makefile.PL>
+or C<Build.PL>.
+
+=item L<http://www.openbsd.org/cgi-bin/cvsweb/src/usr.bin/pkg-config/>
+
+Another perl implementation of pkg-config
+
+=item L<pkgconf|https://github.com/pkgconf/pkgconf>
+
+An alternative C implementation
+
+=item L<pkg-config|https://github.com/ruby-gnome2/pkg-config>
+
+Pure Ruby implementation.
+
+=item L<pykg-config|https://pypi.python.org/pypi/pykg-config/1.2.0>
+
+A Python implementation.
+
+=back
 
 =head1 AUTHOR
 
